@@ -7,13 +7,16 @@ class GitlabEpic:
     GitlabEpic is a Gitlab Epic.
     """
 
-    def __init__(self, id: str = None, iid: str = None, epic: dict = None, group_id: str = None, get_notes: bool = False, token :str = configuration.GITLAB_TOKEN, version: str = configuration.GITLAB_API_VERSION):
+    def __init__(self, id: str = None, iid: str = None, epic: dict = None, group_id: str = None, issues: list = None, get_issues: bool = False, get_notes: bool = False, get_participants: bool = False, token :str = configuration.GITLAB_TOKEN, version: str = configuration.GITLAB_API_VERSION):
         """
         Args:
             id (string): GitLab Epic id
             iid (string): GitLab Epic iid
+            issues (list): classes of GitLabIssue
             epic (dictionary): GitLab Epic
+            get_issues (boolean): TRUE if issues should be pulled
             get_notes (boolean): TRUE if notes should be pulled
+            get_participants (boolean): TRUE if issue participants should be pulled
             group_id (string): Gitlab Group id
             token (string): GitLab personal access, ci, or deploy token
             version (string): GitLab API version as base url
@@ -27,8 +30,16 @@ class GitlabEpic:
         self.group_id = self.epic["group_id"] if self.epic else None
         self.id = self.epic["id"] if self.epic else None
         self.iid = self.epic["iid"] if self.epic else None
+        self.issues = self.extract_issues() if get_issues else issues
         self.notes = self.extract_notes() if get_notes else None
 
+        # get all participants
+        pts = [d.extract_participants() for d in self.issues] if self.issues else None
+        participants = [x for y in pts for x in y] if pts else None
+
+        # update self
+        self.participants = [d for d in participants if d["id"] in list(set([x["id"] for x in participants]))] if self.issues and get_participants else None
+
     def extract_issues(self, scope: str = "all", date_start: str = None, date_end: str = None) -> list:
         """
         Extract epic-specific issue data.
