@@ -25,13 +25,14 @@ class GitlabGroup:
         self.group = group if group else (self.connection.query("groups/%s" % id)["data"] if id and token and version else None)
         self.id = self.group["id"] if self.group else None
 
-    def extract_epics(self, date_start: str = None, date_end: str = None, get_notes: bool = False) -> list:
+    def extract_epics(self, date_start: str = None, date_end: str = None, get_issues: bool = False, get_notes: bool = False) -> list:
         """
         Extract group-specific epic data.
 
         Args:
             date_end (string): iso 8601 date value
             date_start (string): iso 8601 date value
+            get_issues (boolean): TRUE if issues should be pulled
             get_notes (boolean): TRUE if notes should be pulled
 
         Returns:
@@ -55,7 +56,7 @@ class GitlabGroup:
             )
 
             # generate GitlabEpic
-            result = [GitlabEpic(epic=d, get_notes=get_notes) for d in epics]
+            result = [GitlabEpic(epic=d, get_issues=get_issues, get_notes=get_notes) for d in epics]
 
         return result
 
